# GABSE
This is the GABSE (Generic Agent-Based Simulation for Engineering) framework.  It provides classes and methods for creating and managing simulations involving agents, their actions, sensors, and the simulation context. It is based on an agent-based modeling technique and is developed with the intention of being lightweight, scalable, and flexible. This package provides the engine, action scheduling, generic agent functionality, and tools for sensory data collection and management.

## Installation
GABSE can be installed from PyPi using pip.

Installation:
```
pip install gabse
```

Update:
```
pip install gabse --upgrade
```

Uninstall:
```
pip uninstall gabse
```

### Dependencies
GABSE has the following dependencies
- sortedcontainers
- numpy
- scipy

## Funactionality
Loreum ipsum.

## EXAMPLES
These are some example simulations that can be used for testing and learning how the GABSE framework functions.
- Zombie apocalypse (both 2D and 3D)

## About
This simulation framework was developed based on PhD research conducted at the Department of Mechanical Engineering, Blekinge Institute of Technology.
